#! /bin/sh

echo	MFPLDSteps=3

##################################################################################################
#	Defines

# source ../../set_variables.sh ../../OEM.ini

VENDOR=`grep '^VENDOR=' ../../OEM.ini 2>/dev/null | sed 's/VENDOR=\(.*\)/\1/'`
if [ -z "$VENDOR" ]; then
	echo "File OEM.ini does not exist or invalid"
	echo "Exit drivers.sh"
	exit 1
fi
VENDOR_UC=`echo $VENDOR | tr a-z A-Z`
VENDOR_LC=`echo $VENDOR | tr A-Z a-z`

if [ -z "$TMP_DIR" ] ; then
	TMP_DIR=/var/tmp
fi
if [ -z "$MFP_INSTALL_DIR" ] ; then
	MFP_INSTALL_DIR=/usr/local/bin/$VENDOR_LC
fi


EPM_PACKAGE_NAME=wc3119
EPM_PACKAGE_COMMON_FILE_LOCATION="../../rd"
EPM_PACKAGE_COMMON_FILE=mfpcommon


#	Defines
##################################################################################################


#USAGE: compareVersions file1 file2
#Versions notation 'x1' 'x1.x2' 'x1.x2.x3'
#	0 ==
#   1 >
#	-1 <
#	2 error
compareVersions()
{
	#	test files exists & readable
	if ! [ -r $1 ] || ! [ -r $2 ] ; then
		echo	2
		return
	fi

	v11=`awk -F '.' '{print $1}' $1`
	v12=`awk -F '.' '{print $2}' $1`
	v13=`awk -F '.' '{print $3}' $1`
	v21=`awk -F '.' '{print $1}' $2`
	v22=`awk -F '.' '{print $2}' $2`
	v23=`awk -F '.' '{print $3}' $2`
	
	rm -f $1
	rm -f $2

	#	test first digits are not empty	
	if ! [ $v11 ] ||  ! [ $v21 ] ; then
		echo	2
		return
	fi
	
	if [ $v11 -gt $v21 ]; then
		echo	1
		return
	fi
	
	if [ $v11 -lt $v21 ]; then
		echo	-1
		return
	fi
	if [ -z $v12 ] && [ -z $v22 ]; then
		echo	0
		return
	fi

	if [ $v12 ] && [ $v22 ]; then
     	if [ $v12 -gt $v22 ]; then
     		echo	1
     		return
     	fi
     	if [ $v12 -lt $v22 ]; then
     		echo	-1
     		return
     	fi
     	if [ -z $v13 ] && [ -z $v23 ]; then
     		echo	0
     		return
     	fi
	
		if [ $v13 ] && [ $v23 ]; then
         	if [ $v13 -gt $v23 ]; then
         		echo	1
         		return
         	fi
         	if [ $v13 -lt $v23 ]; then
         		echo	-1
         		return
         	fi
         	
			echo	0
			return
		fi
	fi

	echo	2
	return
}

######################################################################################

status=1

if [ "$1" == "uninstall" ]; then
	ACTION=uninstall
else
	ACTION=install
fi

case $ACTION in
	install)

echo	MFPLDStep=Installing common files...
	
#########################################################################################	
# mfpcommon

		echo	'#########################################################################################'
		bShallInstall=1
		if [ -r $MFP_INSTALL_DIR/$EPM_PACKAGE_COMMON_FILE.version ] ; then
			head -1 $MFP_INSTALL_DIR/$EPM_PACKAGE_COMMON_FILE.version > $TMP_DIR/dummy1$$
			head -1 $EPM_PACKAGE_COMMON_FILE_LOCATION/$EPM_PACKAGE_COMMON_FILE.version > $TMP_DIR/dummy2$$
			cat $TMP_DIR/dummy1$$
			cat $TMP_DIR/dummy2$$
			verCmp=`compareVersions $TMP_DIR/dummy1$$ $TMP_DIR/dummy2$$`

#			if [ "$verCmp" == "0" ] || [ "$verCmp" == "1" ] ; then
#				# Installed version is less or equal - shall not install
			if [ "$verCmp" == "1" ] ; then
				# Version being installed is less - shall not install
				bShallInstall=0
			fi
		fi
		if [ $bShallInstall -eq 1 ] ; then
			echo	'Installing mfpcommon...'
			CUR_DIR=$PWD
			cd "$EPM_PACKAGE_COMMON_FILE_LOCATION"
			
			__MFP_INSTALL__=1; export __MFP_INSTALL__
			
			sh $EPM_PACKAGE_COMMON_FILE.install now
			cd "$CUR_DIR"
		fi
		
# mfpcommon
#########################################################################################	

echo	MFPLDProgress=100

echo	MFPLDStep=Installing MFP drivers...

#########################################################################################	
# driver package

		echo	'#########################################################################################'
		bShallInstall=1
		if [ -r $MFP_INSTALL_DIR/$EPM_PACKAGE_NAME.version ] ; then
			head -1 $MFP_INSTALL_DIR/$EPM_PACKAGE_NAME.version > $TMP_DIR/dummy1$$
			head -1 $EPM_PACKAGE_NAME.version > $TMP_DIR/dummy2$$
#			cat $TMP_DIR/dummy1$$
#			cat $TMP_DIR/dummy2$$
			verCmp=`compareVersions $TMP_DIR/dummy1$$ $TMP_DIR/dummy2$$`

#			if [ "$verCmp" == "0" ] || [ "$verCmp" == "1" ] ; then
#				# Installed version is less or equal - shall not install
			if [ "$verCmp" == "1" ] ; then
				# Version being installed is less - shall not install
				bShallInstall=0
			else
				__MFP_OVERWRITE_DRIVER__=1; export __MFP_OVERWRITE_DRIVER__
			fi
		fi
		

		status=0
		if [ $bShallInstall -eq 1 ] ; then
			echo	'Installing MFP drivers package...'
			sh $EPM_PACKAGE_NAME.install now
			status=$?
			if [ $status -eq 0 ]; then
				echo	'MFP driver package installation succedded.'
			else
				echo	'MFP driver package installation failed.'
			fi
		fi
		
# driver package
#########################################################################################	

echo	MFPLDProgress=100

		;;
	uninstall)
		echo	'Uninstalling MFP driver package...'
		sh $EPM_PACKAGE_NAME.remove now
		status=$?
		if [ $status -eq 0 ]; then
			echo	'MFP driver package was successfully uninstalled.'
		else
			echo	'Unable to uninstall MFP driver package.'
		fi
		CUR_DIR=$PWD
		cd "$EPM_PACKAGE_COMMON_FILE_LOCATION"
		sh $EPM_PACKAGE_COMMON_FILE.remove now
		cd "$CUR_DIR"
		;;
	*)
		echo driver.sh - wrong action selected. Setup terminated.
		status=1
esac

exit	$status;



